@@ -2,9 +2,6 @@
 pref("mousewheel.withcontrolkey.action", 1);
 pref("mousewheel.withcontrolkey.numlines", 1);
 pref("mousewheel.withcontrolkey.sysnumlines", false);
-// fix horizontal scroll with 2nd wheel, see bug #148557
-pref("mousewheel.horizscroll.withnokey.action", 0);
-pref("mousewheel.horizscroll.withnokey.sysnumlines", true);
 
 // don't allow opening file:/// URLs on pages from network sources (http, etc.)
 pref("security.checkloaduri", true);
@@ -32,7 +29,6 @@ pref("helpers.global_mime_types_file", "");
 pref("helpers.private_mime_types_file", "");
 
 // use google for keywords
-pref("keyword.URL", "http://www.google.com/search?ie=UTF-8&oe=UTF-8&q=");
 pref("keyword.enabled", true);
 
 // disable usless security warnings
