@@ -15,8 +15,15 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
+ *  $Id: EphyUtils.cpp,v 1.3 2004/07/30 19:56:08 chpe Exp $
  */
 
+#include "mozilla-config.h"
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "EphyUtils.h"
 
 #include <nsIServiceManager.h>
