@@ -1,6 +1,6 @@
 /*  vim:set ts=8 noet sw=8:
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright (C) 2000-2004 Marco Pesenti Gritti
+ *  Copyright (C) 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,9 +16,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed-single.cpp,v 1.83 2004/07/04 23:56:26 chpe Exp $
+ *  $Id: mozilla-embed-single.cpp,v 1.91 2004/08/08 18:11:56 chpe Exp $
  */
 
+#include "mozilla-config.h"
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -43,6 +45,7 @@
 #include "EphySingle.h"
 #include "EphyBrowser.h"
 #include "EphyUtils.h"
+#include "MozillaPrivate.h"
 
 #include <glib/gi18n.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
@@ -73,7 +76,6 @@
 // FIXME: For setting the locale. hopefully gtkmozembed will do itself soon
 #include <nsIChromeRegistry.h>
 #include <nsILocaleService.h>
-#include <nsIProtocolProxyService.h>
 #include <nsIHttpAuthManager.h>
 #include <nsICacheService.h>
 #include <nsIFontEnumerator.h>
@@ -203,6 +205,22 @@ mozilla_set_default_prefs (MozillaEmbedSingle *mes)
 		return FALSE;
         }
                                                                                                                              
+	nsCOMPtr<nsIPrefBranch> pref;
+	prefService->GetBranch ("", getter_AddRefs(pref));
+	NS_ENSURE_TRUE (pref, FALSE);
+
+	/* We do this before reading the user pref file so that the user
+	 * still can overwrite this pref.
+	 * We don't use the default-prefs.js file since that cannot be
+	 * localised (see bug #144909).
+	 */
+	/* translators: this is the URL that searches from the location
+	 * entry get directed to. The search terms will be _appended_ to it,
+	 * in url-escaped UTF-8; that means that if you're choosing google,
+	 * the 'q=' part needs to come last.
+	 */
+	pref->SetCharPref ("keyword.URL", _("http://www.google.com/search?ie=UTF-8&oe=UTF-8&q="));
+
         /* Load the default user preferences as well.  This also makes the
            prefs to be saved in the user's prefs.js file, instead of messing up
            our global defaults file. */
@@ -212,10 +230,6 @@ mozilla_set_default_prefs (MozillaEmbedSingle *mes)
                 g_warning ("failed to read user preferences, error: %x", rv);
         }
 
-        nsCOMPtr<nsIPrefBranch> pref;
-        prefService->GetBranch ("", getter_AddRefs(pref));
-	NS_ENSURE_TRUE (pref, FALSE);
-
 	/* FIXME We need to do this because mozilla doesnt set product
 	sub for embedding apps */
 	pref->SetCharPref ("general.useragent.vendor", "Epiphany");
@@ -293,9 +307,9 @@ mozilla_setup_colors (MozillaEmbedSingle *mes)
 
 static void 
 mozilla_embed_single_new_window_orphan_cb (GtkMozEmbedSingle *embed,
-                      		          GtkMozEmbed **retval, 
-					  guint chrome_mask,
-                           		  EphyEmbedSingle *shell)
+					   GtkMozEmbed **retval, 
+					   guint chrome_mask,
+					   EphyEmbedSingle *shell)
 {
  	g_assert (chrome_mask & GTK_MOZ_EMBED_FLAG_OPENASCHROME);
 
@@ -367,18 +381,18 @@ have_gnome_url_handler (const gchar *protocol)
 static nsresult
 getUILang (nsAString& aUILang)
 {
-	nsresult result;
+	nsresult rv;
 
-	nsCOMPtr<nsILocaleService> localeService = do_GetService (NS_LOCALESERVICE_CONTRACTID, &result);
-	if (NS_FAILED (result) || !localeService)
+	nsCOMPtr<nsILocaleService> localeService = do_GetService (NS_LOCALESERVICE_CONTRACTID);
+	if (!localeService)
 	{
 		g_warning ("Could not get locale service!\n");
 		return NS_ERROR_FAILURE;
 	}
 
-	result = localeService->GetLocaleComponentForUserAgent (aUILang);
+	rv = localeService->GetLocaleComponentForUserAgent (aUILang);
 
-	if (NS_FAILED (result))
+	if (NS_FAILED (rv))
 	{
 		g_warning ("Could not determine locale!\n");
 		return NS_ERROR_FAILURE;
@@ -390,22 +404,22 @@ getUILang (nsAString& aUILang)
 static nsresult
 mozilla_init_chrome (void)
 {
-	nsresult result;
+	nsresult rv;
 	nsEmbedString uiLang;
 
 	nsCOMPtr<nsIXULChromeRegistry> chromeRegistry = do_GetService (NS_CHROMEREGISTRY_CONTRACTID);
 	NS_ENSURE_TRUE (chromeRegistry, NS_ERROR_FAILURE);
 
 	// Set skin to 'classic' so we get native scrollbars.
-	result = chromeRegistry->SelectSkin (nsEmbedCString("classic/1.0"), PR_FALSE);
-	NS_ENSURE_SUCCESS (result, NS_ERROR_FAILURE);
+	rv = chromeRegistry->SelectSkin (nsEmbedCString("classic/1.0"), PR_FALSE);
+	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
 	// set locale
-	result = chromeRegistry->SetRuntimeProvider(PR_TRUE);
-	NS_ENSURE_SUCCESS (result, NS_ERROR_FAILURE);
+	rv = chromeRegistry->SetRuntimeProvider(PR_TRUE);
+	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
-	result = getUILang(uiLang);
-	NS_ENSURE_SUCCESS (result, NS_ERROR_FAILURE);
+	rv = getUILang(uiLang);
+	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
 	nsEmbedCString cUILang;
 	NS_UTF16ToCString (uiLang, NS_CSTRING_ENCODING_UTF8, cUILang);
@@ -419,8 +433,7 @@ mozilla_init_observer (MozillaEmbedSingle *single)
 	EphySingle *es;
 
 	es = new EphySingle ();
-	nsCOMPtr<nsIObserver> guard = NS_STATIC_CAST (nsIObserver *, es);
-	if (!guard) return;
+	NS_ADDREF (single->priv->mSingleObserver = es);
 
 	nsresult rv;
 	rv = es->Init (EPHY_EMBED_SINGLE (single));
@@ -429,8 +442,6 @@ mozilla_init_observer (MozillaEmbedSingle *single)
 		g_warning ("Failed to initialise EphySingle!\n");
 		return;
 	}
-
-	NS_ADDREF (single->priv->mSingleObserver = es);
 }
 
 static gboolean
@@ -511,7 +522,6 @@ mozilla_embed_single_dispose (GObject *object)
 	{
 		single->priv->mSingleObserver->Detach ();
 		NS_RELEASE (single->priv->mSingleObserver);
-		delete single->priv->mSingleObserver;
 		single->priv->mSingleObserver = nsnull;
 	}
 }
@@ -581,23 +591,6 @@ impl_get_offline_mode (EphyEmbedSingle *shell)
 	return isOffline;
 }
 
-static void
-impl_load_proxy_autoconf (EphyEmbedSingle *shell,
-			  const char* url)
-{
-	g_assert (url != NULL);
-
-        nsCOMPtr<nsIProtocolProxyService> pps =
-                do_GetService ("@mozilla.org/network/protocol-proxy-service;1");
-	if (!pps) return;
-
-#if MOZILLA_CHECK_VERSION4 (1, 8, MOZILLA_ALPHA, 2)
-	pps->ConfigureFromPAC (nsEmbedCString (url));
-#else
-	pps->ConfigureFromPAC (url);
-#endif
-}
-
 static GList *
 impl_get_font_list (EphyEmbedSingle *shell,
 		    const char *langGroup)
@@ -635,7 +628,7 @@ impl_get_font_list (EphyEmbedSingle *shell,
 static GList *
 impl_list_cookies (EphyCookieManager *manager)
 {
-	nsresult result;
+	nsresult rv;
 	GList *cookies = NULL;
 	
 	nsCOMPtr<nsICookieManager> cookieManager = 
@@ -652,8 +645,8 @@ impl_list_cookies (EphyCookieManager *manager)
 	     cookieEnumerator->HasMoreElements(&enumResult))
 	{
 		nsCOMPtr<nsICookie> keks;
-		result = cookieEnumerator->GetNext (getter_AddRefs(keks));
-		if (NS_FAILED (result) || !keks) continue;
+		rv = cookieEnumerator->GetNext (getter_AddRefs(keks));
+		if (NS_FAILED (rv) || !keks) continue;
 
 		EphyCookie *cookie = mozilla_cookie_to_ephy_cookie (keks);
 		if (!cookie) continue;
@@ -906,28 +899,31 @@ impl_permission_manager_list (EphyPermissionManager *manager,
 	return list;
 }
 
-static void
+static GtkWidget * 
 impl_open_window (EphyEmbedSingle *single,
 		  EphyEmbed *parent,
 		  const char *address,
+		  const char *name,
 		  const char *features)
 {
 	nsCOMPtr<nsIDOMWindow> domWindow;
-	nsCOMPtr<nsIDOMWindow> dummy;
 
 	if (parent)
 	{
 		EphyBrowser *browser;
 
 		browser = (EphyBrowser *) _mozilla_embed_get_ephy_browser (MOZILLA_EMBED(parent));
-		g_return_if_fail (browser != NULL);
+		g_return_val_if_fail (browser != NULL, NULL);
 
 		browser->GetDOMWindow (getter_AddRefs (domWindow));
 	}
 
 	nsCOMPtr<nsIWindowWatcher> wWatch(do_GetService ("@mozilla.org/embedcomp/window-watcher;1"));
-	wWatch->OpenWindow (domWindow, address, "", features, nsnull,
-			    getter_AddRefs (dummy));
+	nsCOMPtr<nsIDOMWindow> newWindow;
+	wWatch->OpenWindow (domWindow, address, name, features, nsnull,
+			    getter_AddRefs (newWindow));
+
+	return MozillaFindEmbed (newWindow);
 }
 
 static void
@@ -950,7 +946,6 @@ ephy_embed_single_iface_init (EphyEmbedSingleIface *iface)
 	iface->clear_auth_cache = impl_clear_auth_cache;
 	iface->set_offline_mode = impl_set_offline_mode;
 	iface->get_offline_mode = impl_get_offline_mode;
-	iface->load_proxy_autoconf = impl_load_proxy_autoconf;
 	iface->get_font_list = impl_get_font_list;
 	iface->open_window = impl_open_window;
 }
