@@ -16,13 +16,17 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-notifiers.cpp,v 1.45.4.3 2004/10/28 12:25:51 chpe Exp $
+ *  $Id: mozilla-notifiers.cpp,v 1.51 2004/07/30 19:56:08 chpe Exp $
  */
 
+#include "mozilla-config.h"
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
+#include "mozilla-version.h"
+
 #include "ephy-embed-single.h"
 #include "ephy-embed-shell.h"
 #include "mozilla-notifiers.h"
@@ -36,16 +40,21 @@
 #include <stdio.h>
 #include <string.h>
 #include <locale.h>
-#include <glib/gi18n.h>
 #include <stdlib.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtksettings.h>
 
 #include <nsCOMPtr.h>
+#include <nsEmbedString.h>
 #include <nsIPrefService.h>
 #include <nsIServiceManager.h>
+/* we don't use glib/gi18n.h here because we need gnome_i18n_get_language_list() */
 #include <libgnome/gnome-i18n.h>
 
+#ifdef ALLOW_PRIVATE_API
+#include <nsIProtocolProxyService.h>
+#endif
+ 
 #define MOZILLA_PREF_NO_PROXIES "network.proxy.no_proxies_on"
 #define MIGRATE_PIXEL_SIZE
 
@@ -98,6 +107,11 @@ mozilla_proxy_mode_notifier (GConfClient *client,
 			     GConfEntry *entry,
 			     EphyEmbedSingle *single);
 static void
+mozilla_proxy_autoconfig_notifier (GConfClient *client,
+			           guint cnxn_id,
+			           GConfEntry *entry,
+			           EphyEmbedSingle *single);
+static void
 mozilla_proxy_mode_notifier (GConfClient *client,
 		             guint cnxn_id,
 		             GConfEntry *entry,
@@ -168,6 +182,8 @@ custom_notifiers [] =
 	  (GConfClientNotifyFunc) mozilla_language_notifier },
 	{ CONF_NETWORK_PROXY_MODE,
 	  (GConfClientNotifyFunc) mozilla_proxy_mode_notifier },
+	{ CONF_NETWORK_PROXY_AUTO_URL,
+	  (GConfClientNotifyFunc) mozilla_proxy_autoconfig_notifier },
 	{ CONF_NETWORK_CACHE_SIZE,
           (GConfClientNotifyFunc) mozilla_cache_size_notifier },
 	{ CONF_SECURITY_COOKIES_ACCEPT,
@@ -341,6 +357,29 @@ mozilla_font_notifier (GConfClient *client,
 	}
 }
 
+static void
+mozilla_proxy_autoconfig_notifier (GConfClient *client,
+		       	           guint cnxn_id,
+		       		   GConfEntry *entry,
+		       		   EphyEmbedSingle *single)
+{
+        nsCOMPtr<nsIProtocolProxyService> pps =
+                do_GetService ("@mozilla.org/network/protocol-proxy-service;1");
+        if (!pps) return;
+
+	char *url = eel_gconf_get_string (entry->key);
+	if (url && url[0] != '\0')
+	{
+#if MOZILLA_CHECK_VERSION4 (1, 8, MOZILLA_ALPHA, 2)
+	        pps->ConfigureFromPAC (nsEmbedCString (url));
+#else
+	        pps->ConfigureFromPAC (url);
+#endif
+	}
+
+	g_free (url);
+}
+
 static void
 add_notification_and_notify (GConfClient		*client,
 			     const char 		*key,
@@ -839,4 +878,3 @@ mozilla_proxy_ignore_notifier (GConfClient *client,
 	g_slist_foreach (hosts, (GFunc) g_free, NULL);
 	g_slist_free (hosts);
 }
-
