@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-bookmarks-editor.c,v 1.139 2004/07/14 16:44:35 marco Exp $
+ * $Id: ephy-bookmarks-editor.c,v 1.141 2004/08/06 14:34:07 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -44,7 +44,6 @@
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
 #include <libgnomeui/gnome-stock-icons.h>
-#include <libgnomevfs/gnome-vfs-uri.h>
 #include <string.h>
 
 #include "ephy-bookmarks-editor.h"
@@ -286,7 +285,7 @@ cmd_add_topic (GtkAction *action,
 	node = ephy_bookmarks_add_keyword (editor->priv->bookmarks,
 				           _("Type a topic"));
 	ephy_node_view_select_node (EPHY_NODE_VIEW (editor->priv->key_view), node);
-	ephy_node_view_edit (EPHY_NODE_VIEW (editor->priv->key_view));
+	ephy_node_view_edit (EPHY_NODE_VIEW (editor->priv->key_view), TRUE);
 	add_text_renderer_monitor (editor);
 }
 
@@ -303,11 +302,11 @@ cmd_rename (GtkAction *action,
 {
 	if (ephy_node_view_is_target (EPHY_NODE_VIEW (editor->priv->bm_view)))
 	{
-		ephy_node_view_edit (EPHY_NODE_VIEW (editor->priv->bm_view));
+		ephy_node_view_edit (EPHY_NODE_VIEW (editor->priv->bm_view), FALSE);
 	}
 	else if (ephy_node_view_is_target (EPHY_NODE_VIEW (editor->priv->key_view)))
 	{
-		ephy_node_view_edit (EPHY_NODE_VIEW (editor->priv->key_view));
+		ephy_node_view_edit (EPHY_NODE_VIEW (editor->priv->key_view), FALSE);
 	}
 	add_text_renderer_monitor (editor);
 }
