@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmarks.c,v 1.84 2004/07/31 11:58:56 chpe Exp $
+ *  $Id: ephy-bookmarks.c,v 1.85 2004/08/06 12:49:19 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -1110,7 +1110,7 @@ ephy_bookmarks_solve_smart_url (EphyBookmarks *eb,
 
 	smarturl_only = get_smarturl_only (smart_url);
 
-	s = g_string_new ("");
+	s = g_string_new (NULL);
 
 	encoding = smart_url_options_get (smart_url, "encoding");
 	if (!encoding)
