@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-encoding-dialog.c,v 1.15 2004/05/01 20:47:00 chpe Exp $
+ *  $Id: ephy-encoding-dialog.c,v 1.16 2004/07/14 16:44:35 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -315,11 +315,13 @@ ephy_encoding_dialog_init (EphyEncodingDialog *dialog)
 	ephy_node_view_add_column (EPHY_NODE_VIEW (treeview), _("Encodings"),
 				   G_TYPE_STRING,
 				   EPHY_NODE_ENCODING_PROP_TITLE_ELIDED,
-				   -1,
-				   EPHY_NODE_VIEW_AUTO_SORT |
 				   EPHY_NODE_VIEW_SEARCHABLE,
 				   NULL);
 
+	ephy_node_view_set_sort (EPHY_NODE_VIEW (treeview), G_TYPE_STRING,
+				 EPHY_NODE_ENCODING_PROP_TITLE_ELIDED,
+				 GTK_SORT_ASCENDING);
+
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW(treeview), FALSE);
