@@ -16,9 +16,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-location-action.c,v 1.21.2.1 2004/04/09 21:10:13 chpe Exp $
+ *  $Id: ephy-location-action.c,v 1.25 2004/08/04 10:33:12 chpe Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "ephy-location-action.h"
 #include "ephy-location-entry.h"
 #include "ephy-shell.h"
@@ -125,16 +129,15 @@ action_activated_cb (GtkEntryCompletion *completion,
 }
 
 static void
-location_url_activate_cb (EphyLocationEntry *entry,
+location_url_activate_cb (GtkEntry *entry,
 			  EphyLocationAction *action)
 {
-	char *content;
+	const char *content;
 
-	content = gtk_editable_get_chars (GTK_EDITABLE(entry), 0, -1);
+	content = gtk_entry_get_text (entry);
 	if (content)
 	{
 		g_signal_emit (action, signals[GO_LOCATION], 0, content);
-		g_free (content);
 	}
 }
 
@@ -268,7 +271,9 @@ connect_proxy (GtkAction *action, GtkWidget *proxy)
 					 G_CALLBACK (user_changed_cb), action, 0);
 	}
 
-	/* we need to connect to this before chaining up, since gtkaction's
+	/* FIXME: when porting to gtk+ 2.6, use "visible-overflown" 
+	 * property on GtkAction instead.
+	 * we need to connect to this before chaining up, since gtkaction's
 	 * connect_proxy connects a routine there which uses create_menu_item
 	 * method to generate a menu proxy (and create_menu_item CANNOT return
 	 * NULL. See bug #133446.
@@ -287,11 +292,15 @@ disconnect_proxy (GtkAction *action, GtkWidget *proxy)
 
 	if (EPHY_IS_LOCATION_ENTRY (proxy))
 	{
+		GtkWidget *entry;
+
+		entry = GTK_BIN (proxy)->child;
+
 		g_signal_handlers_disconnect_by_func
 			(action, G_CALLBACK (sync_address), proxy);
 
 		g_signal_handlers_disconnect_by_func
-			(proxy, G_CALLBACK (location_url_activate_cb), action);
+			(entry, G_CALLBACK (location_url_activate_cb), action);
 
 		g_signal_handlers_disconnect_by_func
 			(proxy, G_CALLBACK (user_changed_cb), action);
@@ -315,7 +324,6 @@ ephy_location_action_set_property (GObject *object,
 			break;
 		case PROP_EDITABLE:
 			action->priv->editable = g_value_get_boolean (value);
-			g_object_notify (G_OBJECT (action), "editable");
 			break;
 	}
 }
@@ -561,6 +569,6 @@ ephy_location_action_set_address (EphyLocationAction *action,
 	LOG ("set_address %s", address)
 
 	g_free (action->priv->address);
-	action->priv->address = g_strdup (address ? address : "");
+	action->priv->address = g_strdup (address);
 	g_object_notify (G_OBJECT (action), "address");
 }
